import React, { useState,useEffect } from 'react'
import { useHistory } from 'react-router-dom'
import { ButtonComponent, InputComponent, TextareaComponent } from '../Utilities/Button/Button'
import { postData,getClientData } from "../../services/ProjectService";
import *  as Validation from '../Utilities/Validation';
import { Astrick } from '../Utilities/Style';
function CreateProject() {
    const history = useHistory();

    const [projectData, setProjectData] = useState();
    const [userData, setUserData] = useState();

    const changeHandler = (e) => {
        const { name, value } = e.target;
        setProjectData({
            ...projectData,
            [name]: value,
        });
    }


    const submitHandler = (e) => {
        console.log(e);
        e.preventDefault();
        const data = new FormData(e.target);
        // const form ={};
        // data.forEach((value, key) => {
        //     value=value ? value : null;
        //     form[key]=value 
        // });
        postData(data).then(res => {
            if(res.status===200)
            {
                const data=res.data;
                var returnValue = { show: true, type: "danger", message: data.message };
                if (data.status === 1) {
                    returnValue.type = "success";
                }
                history.push({
                    pathname: '/Project',
                    state: { showAlert: true, alertData: returnValue }
                });
            }
        });

    }

    async function get(){
        const tempData = [];
        const temp=[];
        const temp1=[];
        await getClientData().then((res) => {
            console.log('check 1');
            console.log(res);
            if (res.status == 200) {
                const data= res.data.data;
                for (const key in data) {
                    tempData.push({
                        value: data[key].id,
                        label: data[key].name
                    })
                }
                setUserData(tempData);   
            }
        });
    }
    useEffect(() => {
        get();
        // if(location && location.state){
        //     setShowAlert(location.state.alertData);
        // }
    }, [])
    return (
        <>
            <div className="body d-flex py-3">
                <div className="container-xxl">
                    <div className="row clearfix g-3">
                        <div className="col-xl-12 col-lg-12 col-md-12 flex-column">
                            {/*************** HEADING ***************/}
                            <div className="card">
                                <div className="card-header d-flex justify-content-between bg-transparent 
                                border-bottom-0">
                                    <h2 className="mb-0 fw-bold ">Add Project</h2>
                                </div>
                            </div>
                            {/*************** TABLE ***************/}
                            <div className='card mt-2'>
                                <div className='card-body'>

                                    <form onSubmit={submitHandler} method="post" enctype='multipart/form-data'>

                                        <div className="form-group row mt-3">
                                            <label htmlFor="inputEmail3" className="col-sm-2 col-form-label">
                                                <b>Project Name : <Astrick color='red'/></b>
                                            </label>
                                            <div className="col-sm-10">
                                                <InputComponent
                                                    id="project_name"
                                                    name="project_name"
                                                    placeholder=""
                                                    getInputValue={e => { changeHandler(e); } }
                                                    onInputKey={e => { Validation.CharactersOnly(e) } }
                                                    required={true}
                                                />
                                            </div>
                                        </div>

                                        <div className="form-group row mt-2">
                                            <label htmlFor="" className="col-sm-2 col-form-label">
                                                <b>Description : <Astrick color='red'/></b>
                                            </label>
                                            <div className="col-sm-10">
                                                <TextareaComponent
                                                    id="description"
                                                    name="description"
                                                    required={true}
                                                    getInputValue={changeHandler}
                                                />
                                            </div>
                                        </div>

                                        <div className="form-group row mt-2">
                                            <label htmlFor="" className="col-sm-2 col-form-label">
                                                <b>Client : </b>
                                            </label>
                                            <div className="col-sm-10">
                                                <select className="form-control form-control-sm col-sm-9" id="client_id" name="client_id" required={true} onChange={changeHandler}>
                                                    <option value="">Select Client</option>
                                                    {userData?.map(function(item, i){
                                                            return <option key={i} value={item.value}>{item.label}</option>
                                                        })
                                                    }
                                                </select>
                                            </div>
                                        </div>

                                        <div className="form-group row mt-3">
                                            <label htmlFor="inputEmail3" className="col-sm-2 col-form-label">
                                                <b>GIT Project URL : </b>
                                            </label>
                                            <div className="col-sm-10">
                                                <InputComponent
                                                    id="git_url"
                                                    name="git_url"
                                                    placeholder=""
                                                    getInputValue={e => { changeHandler(e); } }
                                                />
                                            </div>
                                        </div>

                                        <div className="form-group row mt-3">
                                            <label htmlFor="inputEmail3" className="col-sm-2 col-form-label">
                                                <b>API Document Link : </b>
                                            </label>
                                            <div className="col-sm-10">
                                                <InputComponent
                                                    id="api_document_link"
                                                    name="api_document_link"
                                                    placeholder=""
                                                    getInputValue={e => { changeHandler(e); } }
                                                />
                                            </div>
                                        </div>

                                        <div className="form-group row mt-3">
                                            <label htmlFor="inputEmail3" className="col-sm-2 col-form-label">
                                                <b>Project Logo : </b>
                                            </label>
                                            <div className="col-sm-10">
                                                <input type="file"
                                                    id="logo"
                                                    name="logo"
                                                />
                                            </div>
                                        </div>

                                        <div className="mt-3" style={{ 'textAlign': 'right' }}>

                                            <ButtonComponent type="Submit" buttonColor="primary" textColor="white" text="Add"
                                            icon={{type:"Add",color:"white",size:"15px"}}/>
                                            <ButtonComponent type="Link" url="/Project" buttonColor="danger" textColor="white" text="Cancel" 
                                            icon={{type:"Cancel",color:"white",size:"15px"}}/>

                                        </div>
                                    </form>

                                </div>
                            </div>

                        </div>
                    </div> {/*ROW*/}
                </div>{/*CONTAINER*/}
            </div>{/*BODY*/}

        </>
    )
}

export default CreateProject 
