import React, { useEffect, useState } from 'react'
import { Link } from 'react-router-dom';
import { getData,putData } from "../../services/SubModuleService";
import {ButtonComponent} from '../Utilities/Button/Button'
import TableNew from "../Utilities/Table/TableNew";
import Alert from '../NotificationComponent/Alert';


function SubModuleComponent({location}) {
    
    const [showAlert, setShowAlert] = useState({show:false,type:null,message:null});

    const [data, setData] = useState(null);

    const columns = [
                        { name: 'Sr', selector: row => row.counter, sortable: true, },
                        { name: 'Project', selector: row => row.project_name, sortable: true, },
                        { name: 'Module', selector: row => row.module_name, sortable: true, },
                        { name: 'Sub Module', selector: row => row.sub_module_name, sortable: true, },
                        { name: 'Description', selector: row => row.description, sortable: true, },
                        { name: 'Created At', selector: row => row.created_at, sortable: true, },
                        { name: 'Created By', selector: row => row.created_by, sortable: true, },
                        { name: 'Action',
                            width:"18%",
                            button: true,
                            ignoreRowClick: true,
                            allowOverflow: true,
                            cell: row => 
                                <div className="d-flex justify-content-center">
                                    
                                    <ButtonComponent type="Link" url={`/SubModule/Edit/`+row.id} buttonColor="primary" textColor="white" 
                                    icon={{type:"Edit",color:"white",size:"15px"}}/>
                                   
                                    <button type="button" className="btn btn-sm btn-danger text-white" 
                                        onClick={handleDelete(row.id)}
                                        >
                                        <i className='icofont-ui-delete text-white' 
                                        style={{fontSize:'15px'}}></i>
                                     
                                    </button>
                                </div> 
                          }
                    ];

    const handleDelete=id=>e=>{ 
        var temp={is_active:0}
        putData(id,temp).then(res =>{
            if(res.status==200){
                if(data.status==1){
                    setShowAlert({show:true,type:"success",message:"Record Deleted"});
                }else{
                    setShowAlert({show:true,type:"success",message:data.message});
                }
                get();
            }
        })
    } 
    
    const get = async() => {
        const tempData=[];
        await getData().then(res =>{
            console.log(res);
            if(res.status===200){
                let counter=1;
                const data=res.data.data;
                for (const key in data) {
                    tempData.push({
                        counter:counter++,  
                        id: data[key].id,
                        project_name: data[key].project_name,
                        module_name: data[key].module_name,
                        sub_module_name: data[key].sub_module_name,
                        description: data[key].description,
                        created_at : data[key].created_at,
                        created_by : data[key].created_by
                    })
                }
                setData(tempData);
            }
        });
    }
    let searchInput = React.createRef();
    const handleSearch=(e)=>{
        e.preventDefault();
        let temp2=searchInput.current.value.toUpperCase();
        const tempData=[];
        data.map((data,index)=>{
            let temp1=data.sub_module_name;
            if(temp1.match(temp2)){
                tempData.push(data)
            }
        })
        setData(null);
        setData(tempData);
    } 
    useEffect(() => {
        get();
        if(location && location.state){
            setShowAlert(location.state.alertData);
        }
    }, [])

    return (
        <>
            <div className="body d-flex py-3">
                <div className="container-xxl">
                    <div className="row clearfix g-3">
                        <div className="col-xl-12 col-lg-12 col-md-12 flex-column">

                            {/*************** HEADING ***************/}
                            <div className="card">
                                <div className="card-header d-flex justify-content-between bg-transparent 
                                border-bottom-0">
                                    <h2 className="mb-0 fw-bold ">Sub Modules</h2>
                                    <Link to="SubModule/Create/"  className="btn btn-dark btn-sm btn-set-task w-sm-100">
                                        <i className="icofont-plus-circle me-2 fs-6" />
                                        Add 
                                    </Link>           
                                </div>
                            </div>

                    
                            {/*************** TABLE ***************/}
                            <div className='card mt-2'>
                                <div className='card-body'>
                                <form onSubmit={handleSearch}>
                                    <div className="form-group row">
                                        <div className='col-md-11 m-0 p-0'>
                                            <input type="text" className='form-control form-control-sm' id="search" name="search"
                                            placeholder='Search...'
                                            ref={searchInput} />
                                        </div>
                                        <div className='col-md-1 m-0 p-0'>
                                            <button className='btn btn-sm btn-warning' type="submit"><i class="icofont-search-1"></i></button>
                                            <button className='btn btn-sm btn-info' type="button" onClick={() => window.location.reload(false)}><i class="icofont-refresh"></i></button>
                                        </div>
                                    </div>
                                </form> 
                                {showAlert.show && <Alert type={showAlert.type} message={showAlert.message}/>}    
                                    {data &&
                                        <TableNew
                                            columns={columns}
                                            data={data}
                                        />
                                    }
                                </div>
                            </div>
                        </div>
                    </div> {/*ROW*/}
                </div>{/*CONTAINER*/}
            </div>{/*BODY*/}
        </>
    )
}

function SubModuleDropdown(props){
    const [data, setData] = useState(null);
    useEffect( async () => {
        const tempData=[];
        await getData().then(res =>{
            if(res.status===200){
            let counter=1;
            const data=res.data.data;
            for (const key in data) {
                tempData.push({
                  counter:counter++,  
                  id: data[key].id,
                  sub_module_name: data[key].sub_module_name
                })
            }
            setData(null);
            setData(tempData);
            }
        });
    }, [])

    return (
        <>
        { data && 
            <select className="form-control form-control-sm" 
                    id={props.id} 
                    name={props.name} 
                    onChange={props.getChangeValue}
                    required={props.required ? true : false }
                    >
                { props.defaultValue == 0 && <option value={0} selected>Select Sub Module</option> }
                { props.defaultValue != 0 && <option value={0}>Select Sub Module</option> }      
                {data.map(function(item, i){
                    if(props.defaultValue && props.defaultValue==item.id){
                        return <option key={i} value={item.id} selected>{item.sub_module_name}</option>
                    }else{
                        return <option key={i} value={item.id}>{item.sub_module_name}</option>
                    }
                })
            }
            </select>
        }
        {!data && <p> Loading....</p>}
        </>
    )
}

export {SubModuleComponent,SubModuleDropdown}